@@ -93,9 +93,11 @@ class KeystoneClientV3(object):
             auth = ka_v3.Password(**auth_info)
 
         else:
-            LOG.error(_LE('Keystone API connection failed: no password, '
-                          'trust_id or token found.'))
-            raise exception.AuthorizationFailure()
+            msg = _LE('Keystone API connection failed: no password, '
+                      'trust_id or token found.')
+            LOG.error(msg)
+            raise exception.AuthorizationFailure(client='keystone',
+                                                 message='reason %s' % msg)
 
         return auth
 
@@ -181,8 +183,11 @@ class KeystoneClientV3(object):
                     self.domain_admin_session
                 )
             except kc_exception.Unauthorized:
-                LOG.error(_LE("Keystone client authentication failed"))
-                raise exception.AuthorizationFailure()
+                msg = _LE("Keystone client authentication failed")
+                LOG.error(msg)
+                raise exception.AuthorizationFailure(client='keystone',
+                                                     message='reason: %s' %
+                                                             msg)
 
             self._trustee_domain_id = access.domain_id
 
