@@ -55,8 +55,6 @@ auth_json=$(cat << EOF
 EOF
 )
 
-#trust is introduced in Keystone v3 version
-AUTH_URL=${AUTH_URL/v2.0/v3}
 content_type='Content-Type: application/json'
 url="$AUTH_URL/auth/tokens"
 USER_TOKEN=`curl -k -s -i -X POST -H "$content_type" -d "$auth_json" $url \
