@@ -46,6 +46,10 @@ if [[ -n "${MASTER_HOSTNAME}" ]]; then
 fi
 sans="${sans},IP:127.0.0.1"
 
+KUBE_SERVICE_IP=$(echo $PORTAL_NETWORK_CIDR | awk 'BEGIN{FS="[./]"; OFS="."}{print $1,$2,$3,$4 + 1}')
+
+sans="${sans},IP:${KUBE_SERVICE_IP}"
+
 cert_dir=/srv/kubernetes
 cert_conf_dir=${cert_dir}/conf
 
@@ -77,8 +81,6 @@ auth_json=$(cat << EOF
 EOF
 )
 
-#trust is introduced in Keystone v3 version
-AUTH_URL=${AUTH_URL/v2.0/v3}
 content_type='Content-Type: application/json'
 url="$AUTH_URL/auth/tokens"
 USER_TOKEN=`curl -k -s -i -X POST -H "$content_type" -d "$auth_json" $url \
