@@ -4,17 +4,14 @@
 
 KUBE_OS_CLOUD_CONFIG=/etc/sysconfig/kube_openstack_config
 
-# kubernetes backend only support keystone v2 at this point
-AUTH_URL=$(echo "$AUTH_URL" | sed 's/v3/v2.0/')
-
 # Generate a the configuration for Kubernetes services
 # to talk to OpenStack Neutron
 cat > $KUBE_OS_CLOUD_CONFIG <<EOF
 [Global]
 auth-url=$AUTH_URL
-username=$USERNAME
-password=$PASSWORD
-tenant-name=$TENANT_NAME
+user-id=$TRUSTEE_USER_ID
+password=$TRUSTEE_PASSWORD
+trust-id=$TRUST_ID
 [LoadBalancer]
 subnet-id=$CLUSTER_SUBNET
 create-monitor=yes
