@@ -9,8 +9,8 @@ REASON="Setup complete"
 DATA="OK"
 UUID=`uuidgen`
 
-data=$(echo '{"Status": "'${STATUS}'", "Reason": "'$REASON'", "Data": "'${DATA}'", "Id": "'$UUID'"}')
+data=$(echo '{"status": "'${STATUS}'", "reason": "'$REASON'", "data": "'${DATA}'", "id": "'$UUID'"}')
 
 curl -k -i -X POST -H "Content-Type: application/json" -H "X-Auth-Token: $WAIT_HANDLE_TOKEN" \
-    --data-binary "'$data'" \
+    --data-binary "$data" \
     "$WAIT_HANDLE_ENDPOINT"
