@@ -67,6 +67,7 @@ chmod 644 $CONF_FILE
 
 SCRIPT=/usr/local/bin/notify-heat
 
+UUID=`uuidgen`
 cat > $SCRIPT << EOF
 #!/bin/sh
 until etcdctl \
@@ -79,9 +80,8 @@ do
     sleep 5
 done
 
-UUID=`uuidgen`
 curl -k -i -X POST -H 'Content-Type: application/json' -H 'X-Auth-Token: $WAIT_HANDLE_TOKEN' \
-    --data-binary "'"'{"Status": "SUCCESS", "Reason": "Swarm agent ready", "Data": "OK", "Id": "'${UUID}'"}'"'" \
+    --data-binary '{"status": "SUCCESS", "reason": "Swarm agent ready", "data": "OK", "id": "${UUID}"}' \
     "$WAIT_HANDLE_ENDPOINT"
 EOF
 
