@@ -21,7 +21,6 @@ import six
 from magnum.common import clients
 from magnum.common import exception
 import magnum.conf
-from magnum.i18n import _LE
 from magnum.i18n import _LW
 
 from requests import exceptions as req_exceptions
@@ -247,20 +246,16 @@ class BaseTemplateDefinition(TemplateDefinition):
         extra_params['trustee_username'] = cluster.trustee_username
         extra_params['trustee_password'] = cluster.trustee_password
 
-        # Only pass trust ID into the template when it is needed.
-        if (cluster_template.volume_driver == 'rexray' or
-                cluster_template.registry_enabled):
-            if CONF.trust.cluster_user_trust:
-                extra_params['trust_id'] = cluster.trust_id
-            else:
-                missing_setting = ('trust/cluster_user_trust = True')
-                msg = _LE('This cluster can only be created with %s in '
-                          'magnum.conf')
-                raise exception.ConfigInvalid(msg % missing_setting)
+        # Only pass trust ID into the template if allowed by the config file
+        if CONF.trust.cluster_user_trust:
+            extra_params['trust_id'] = cluster.trust_id
         else:
             extra_params['trust_id'] = ""
 
-        extra_params['auth_url'] = context.auth_url
+        extra_params['auth_url'] = osc.url_for(
+            service_type='identity',
+            interface=CONF.trust.trustee_keystone_interface,
+            version=3)
 
         return super(BaseTemplateDefinition,
                      self).get_params(context, cluster_template, cluster,
